==> Zephyrus-3.6.3.11884.tar.gz: Zephyrus-3.6.3.11884/Zephyrus/map/models.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: models.py 11884 2020-01-20 08:51:15Z Trista $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Trista $
# $Date: 2020-01-20 16:51:15 +0800 (週一, 20 一月 2020) $
# $Revision: 11884 $


from django.db import models
from django.utils.translation import ugettext_lazy as _

from cms.models import CMSPlugin

from Zephyrus.map import settings



class Map(CMSPlugin):
    apiKey = models.CharField(_('API Key'), max_length=100)
    renderTemplate = models.CharField(
        _('Map Template'), max_length=250, blank=True,
        choices=settings.MAP_TEMPLATES,
        default=settings.MAP_DEFAULT_TEMPLATE,
    )
    
    class Meta:
        verbose_name = _("Map")
        verbose_name_plural = _("Map")

class MapPosition(models.Model):
    relatedMap = models.ForeignKey(Map, related_name="positions")
    region = models.CharField(max_length=60, null=True, blank=True)
    name = models.CharField(max_length=200, null=True, blank=True)
    tel = models.CharField(max_length=60, null=True, blank=True)
    email = models.CharField(max_length=60, null=True, blank=True)
    address = models.CharField(max_length=1000, null=True, blank=True)
    coordinate = models.CharField(max_length=100)

    class Meta:
        verbose_name_plural = _('Positions')
        verbose_name = _('Positions')
    
    def __str__(self):
        representative = self.name if self.name else "#" + str(self.id)
        return representative + " | Map:" + str(self.relatedMap.id)

==> Zephyrus-3.6.6.11892.tar.gz: Zephyrus-3.6.6.11892/Zephyrus/map/models.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: models.py 11898 2020-02-04 18:28:40Z Lavender $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2020-02-05 03:28:40 +0900 (週三, 05 二月 2020) $
# $Revision: 11898 $


from django.db import models
from django.utils.translation import ugettext_lazy as _

from cms.models import CMSPlugin

from Zephyrus.map import settings



class Map(CMSPlugin):
    apiKey = models.CharField(_('API Key'), max_length=100)
    renderTemplate = models.CharField(
        _('Map Template'), max_length=250, blank=True,
        choices=settings.MAP_TEMPLATES,
        default=settings.MAP_DEFAULT_TEMPLATE,
    )
    
    class Meta:
        verbose_name = _("Map")
        verbose_name_plural = _("Map")

class MapPosition(models.Model):
    relatedMap = models.ForeignKey(Map, related_name="positions", on_delete=models.CASCADE)
    region = models.CharField(max_length=60, null=True, blank=True)
    name = models.CharField(max_length=200, null=True, blank=True)
    tel = models.CharField(max_length=60, null=True, blank=True)
    email = models.CharField(max_length=60, null=True, blank=True)
    address = models.CharField(max_length=1000, null=True, blank=True)
    coordinate = models.CharField(max_length=100)

    class Meta:
        verbose_name_plural = _('Positions')
        verbose_name = _('Positions')
    
    def __str__(self):
        representative = self.name if self.name else "#" + str(self.id)
        return representative + " | Map:" + str(self.relatedMap.id)
